@@ -189,7 +189,7 @@ impl WordsIterator
     #[must_use]
     fn has_next(&self) -> bool
     {
-        self.words.len() > 0 || self.pending.len() > 0
+        self.words.len() > 0 || !self.pending.is_empty()
     }
 
     #[inline]
@@ -911,6 +911,14 @@ impl FormattedTextBlock
     {
         self.height
     }
+
+    /// The size (in pixels) of this text block.
+    #[inline]
+    #[must_use]
+    pub fn size(&self) -> Vector2<f32>
+    {
+        Vector2::new(self.width, self.height)
+    }
 }
 
 /// Represents a line of text which has been laid out as part of a block.
