@@ -32,6 +32,7 @@ use crate::font::FormattedTextBlock;
 use crate::font_cache::{GlyphCache, GlyphCacheInterface};
 use crate::glwrapper::*;
 use crate::image::{ImageDataType, ImageHandle, ImageSmoothingMode};
+use crate::Rectangle;
 
 struct AttributeBuffers
 {
@@ -471,20 +472,37 @@ impl Renderer2D
         viewport_size_pixels: Vector2<u32>
     ) -> Result<Self, BacktraceError<ErrorMessage>>
     {
+        log::info!("Creating vertex shader");
+
+        let (vertex_shader_src, fragment_shader_src) = match context.version() {
+            GLVersion::OpenGL2_0 => {
+                log::info!("Using OpenGL 2.0 shaders");
+                (
+                    include_str!("shaders/r2d_vertex_v110.glsl"),
+                    include_str!("shaders/r2d_fragment_v110.glsl")
+                )
+            }
+            GLVersion::WebGL2_0 => {
+                log::info!("Using WebGL 2.0 shaders");
+                (
+                    include_str!("shaders/r2d_vertex_v300es.glsl"),
+                    include_str!("shaders/r2d_fragment_v300es.glsl")
+                )
+            }
+        };
+
         let vertex_shader = context
-            .new_shader(
-                GLShaderType::Vertex,
-                include_str!("shaders/r2d_vertex.glsl")
-            )
+            .new_shader(GLShaderType::Vertex, vertex_shader_src)
             .context("Failed to create Renderer2D vertex shader")?;
 
+        log::info!("Creating fragment shader");
+
         let fragment_shader = context
-            .new_shader(
-                GLShaderType::Fragment,
-                include_str!("shaders/r2d_fragment.glsl")
-            )
+            .new_shader(GLShaderType::Fragment, fragment_shader_src)
             .context("Failed to create Renderer2D fragment shader")?;
 
+        log::info!("Compiling program");
+
         let program = context
             .new_program(
                 &vertex_shader,
@@ -502,6 +520,8 @@ impl Renderer2D
 
         uniforms.set_viewport_size_pixels(context, viewport_size_pixels);
 
+        context.set_viewport_size(viewport_size_pixels);
+
         Ok(Renderer2D {
             context: context.clone(),
             program,
@@ -518,6 +538,8 @@ impl Renderer2D
     {
         self.uniforms
             .set_viewport_size_pixels(&self.context, viewport_size_pixels);
+
+        self.context.set_viewport_size(viewport_size_pixels);
     }
 
     pub fn flush_render_queue(&mut self)
@@ -805,4 +827,24 @@ impl Renderer2D
             vertex_normalized_circle_coords_clockwise
         })
     }
+
+    #[inline]
+    pub(crate) fn set_clip(&mut self, rect: Option<Rectangle<i32>>)
+    {
+        // If we change the clip area, we need to draw everything in a queue
+        // through the current clip before setting new one.
+        self.flush_render_queue();
+        match rect {
+            None => self.context.set_enable_scissor(false),
+            Some(rect) => {
+                self.context.set_enable_scissor(true);
+                self.context.set_clip(
+                    rect.top_left().x,
+                    rect.top_left().y,
+                    rect.width(),
+                    rect.height()
+                )
+            }
+        }
+    }
 }
