@@ -14,6 +14,9 @@
  *  limitations under the License.
  */
 
+#[cfg(not(all(target_arch = "x86_64", target_os = "linux")))]
+compile_error!("The automated tests currently support Linux x86_64 only");
+
 use std::convert::TryInto;
 use std::os::raw::c_void;
 
@@ -729,6 +732,45 @@ fn main()
         })
     });
 
+    tests.push(GLTest {
+        width: 100,
+        height: 100,
+        name: "clip_area".to_string(),
+        action: Box::new(|renderer| {
+            renderer.draw_frame(|graphics| {
+                graphics.clear_screen(Color::LIGHT_GRAY);
+
+                graphics.set_clip(Some(Rectangle::from_tuples((10, 10), (30, 20))));
+                graphics.draw_rectangle(
+                    Rectangle::from_tuples((0.0, 0.0), (20.0, 40.0)),
+                    Color::RED
+                );
+                graphics.draw_rectangle(
+                    Rectangle::from_tuples((20.0, 0.0), (40.0, 40.0)),
+                    Color::BLUE
+                );
+            });
+        })
+    });
+
+    tests.push(GLTest {
+        width: 400,
+        height: 150,
+        name: "clip_area_2".to_string(),
+        action: Box::new(|renderer| {
+            let typeface = Font::new(NOTO_SANS_REGULAR_BYTES).unwrap();
+
+            let text = typeface.layout_text("Hello World", 100.0, TextOptions::new());
+
+            renderer.draw_frame(|graphics| {
+                graphics.clear_screen(Color::WHITE);
+                graphics.set_clip(Some(Rectangle::from_tuples((25, 25), (250, 75))));
+                graphics.clear_screen(Color::GREEN);
+                graphics.draw_text(Vector2::new(0.0, 0.0), Color::BLACK, &text);
+            });
+        })
+    });
+
     for test in tests {
         log::info!("Running test {}", test.name);
 
